@@ -907,11 +907,21 @@ mag_zoomers_set_cursor_color (gchar *color)
 	{
 	    magnifier_set_cursor_color (magnifier,
 					cursor_color);
-	    magnifier_set_cursor (magnifier,
+	    if (cursor_scale)
+	    {
+		    magnifier_set_cursor (magnifier,
+				  cursor_name, 
+				  CURSOR_SIZE_INVALID, 
+				  cursor_zoom_factor);
+	    }
+	    else
+	    {
+		magnifier_set_cursor (magnifier,
 				  cursor_name, 
 				  cursor_size, 
 				  cursor_zoom_factor);
-
+	    }
+	    
 	}
     }
 }
@@ -1504,17 +1514,16 @@ mag_initialize (MagEventCB mag_event)
 	display_size.width = gdk_screen_width () - 1;
 	display_size.height = gdk_screen_height () - 1;
 	
-        if (!srconf_set_data (MAGNIFIER_DISPLAY_SIZE_X, 
-			      CFGT_INT, 
-			      (gpointer)&display_size.width, 
-			      MAGNIFIER_CONFIG_PATH)
-	) return FALSE;
+        srconf_set_data (MAGNIFIER_DISPLAY_SIZE_X, 
+			 CFGT_INT, 
+			 (gpointer)&display_size.width, 
+			 MAGNIFIER_CONFIG_PATH);
+	
 
-        if (!srconf_set_data (MAGNIFIER_DISPLAY_SIZE_Y, 
-			      CFGT_INT, 
-			      (gpointer)&display_size.height, 
-			      MAGNIFIER_CONFIG_PATH)
-	) return FALSE;
+        srconf_set_data (MAGNIFIER_DISPLAY_SIZE_Y, 
+			 CFGT_INT, 
+			 (gpointer)&display_size.height, 
+			  MAGNIFIER_CONFIG_PATH);
 
 /*vertical split*/
 	 rect.top =  target_rect.top;
